==> PyBB-0.7.3.tar.gz: PyBB-0.7.3/bbs/i18n/ko.py <==
texts = {
'Username':
'ڸ',

'Password':
'н',

'Please enter your username and password to log in':
'ڸ н带 Էϰ αϽñ ٶϴ',

'Forum List':
' ',

'Edit Profile':
'',

'Message Box':
' ',

"Admin Page":
' ',

'Member List':
'ȸ ',

'Search':
'˻',

'Statistic':
'',

'Number of members':
'  ',

'Number of active members':
'Ȱ  ',

'Number of Categories':
'ĳͰ ',

'Number of Forums':
' ',

'Number of threads':
'  ',

'Number of posts':
' Խñ ',

'Latest Post':
'ֱ Խñ',

'Join Us':
'ϱ',

'login':
'α',

'logout':
'α׾ƿ',

'Topics':
'',

'Posts':
'Խñ',

'Latest Post':
'ֱٱ',

'Moderator(s)':
'',

'Registration Information':
' ',

'Items marked with a * are required unless stated otherwise.':
'* ǥõ ׸ ʼԴϴ.',

'UserId': #  messages of userRegisterForm.html
' ID',

'E-mail address':
' ּ',

'Confirm password':
'н Ȯ',

'Profile Information':
' ',

'This information will be publicly viewable':
'  Գ ˴ϴ.',

'Messenger':
'޽',

'Website':
'Ȩ',

'Location':
'Ҽ',

'Occupation':
'',

'Interests':
'',

'Signature':
'',

'This is a block of text that can be added to posts you make. There is a 255 character limit':
'  ۼ  ڿ ٰ ˴ϴ. 255 ̳ ۼϽñ ٶϴ.',

'Preferences':
' ',

'Hide your online status':
'   ',

'Yes':
'',

'No':
'ƴϿ',

'Always notify me of replies':
'׻ 亯 ˸',

'Sends an e-mail when someone replies to a topic you have posted in. This can be changed whenever you post.':
' ۼ  亯 Ϸ ˷ 帳ϴ.  ۼҶ   ֽϴ.',

'Always notify me of memos':
'׻ ޸ ˸',

'Submit':
'Ȯ',

'Reset':
' ۼ',

'forum':
'',

'ALL':
'ü',

'Subject':
'',

'Contents':
'',

'User':
'',

'New Thread':
'ο ',

'Edit or Reply':
' Ǵ ',

'Topic':
'',

'Topic Starter':
'ۼ',

'Replies':
'亯',

'Views':
'ȸ',

'Latest Post':
'ֱ 亯',

'New Password':
' н',

'New Confirm password':
' н Ȯ',

'Avator':
'ƹŸ',

'You can be upload your picture or avator here. it can be only gif or jpg format.':
'  Ǵ ׸ ø  ֽϴ.  GIF JPG ĸ մϴ.',

'Update':
'',

'Forum Name':
' ̸',

'Forum Description':
' ',

'Forum Status':
' ',

'locked':
'',

'unlocked':
' ',

'hidden':
'',

'Moderator':
' ',

'Permissions':
'',

'View':
'',

'all':
'ü',

'member':
'ȸ',

'forumMember':
' ȸ',

'moderator':
' ',

'admin':
'ְ ',

'Read':
'б',

'Post':
'ۼ',

'Reply':
'亯',

'Edit':
'',

'List':
'',

'private':
'ۼ',

'Delete':
'',

'Default Sort':
'⺻ ',

'Thread id':
'Խù ȣ',

'Ascending':
'',

'Descending':
'',

'Create':
'ۼ',

'Forum Manager':
' ',

'User Manager':
'ȸ ',

'User Group Manager':
'ȸ ׷ ',

'Emoticon Manager':
'̸Ƽ ',

'Configuration Manager':
'ȯ漳',

'Add Category':
'īװ ߰ϱ',

'Edit Category':
'īװ ϱ',

'Category Name':
'īװ ̸',

'Do not use':
' Ұ : ',

'Total':
'',

'members':
'',

'New Members (separated by space or new line)':
' ȸ ( Ǵ ͷ )',

'E-mail':
'',

'Level':
'',

'Registered Time':
'',

'Total Posts':
' ۼ',

'joined forums':
'Ե ',

'Change Level':
' ',

'Poster':
'ۼ',

'IP':
'IP',

'Post Reply':
'亯ޱ',

'Do you really want to delete?':
' մϱ?',

'Previous Thread':
'',

'Next Thread':
'',

'prev':
'',

'next':
'',

'DB setup':
'DB ',

'DB tables':
'DB ̺ ',

'site information':
'Ʈ ',

'paths':
'',

'env':
'ȯ',

'page setup':
' ',

'cache':
'ĳ',

'session':
'',

'user levels':
' ',

'dbhost':
'DB ȣƮ',

'dbuser':
'DB ڰ',

'dbpassword':
'DB н',

'dbname':
'DB ̸',

'tablePrefix':
'̺ ̸ λ',

'userTableName':
' ̺ ̸',

'memoTableName':
'޸ ̺ ̸',

'membershipTableName':
'ȸ ̺ ̸',

'siteName':
'Ʈ',

'webmaster':
'',

'HOST_URL':
'ȣƮ URL',

'HTTP_PORT':
'HTTP Ʈ',

'boardStartedDate':
' ',

'groupDescFileName':
'׷켳 ',

'skinPath':
'Ų 丮 ',

'skinImagePath':
'Ų ̹ 丮 ',

'sessionDir':
' 丮 ',

'defaultLanguage':
'⺻(    쿡 ǥõǴ )',

'maxFileSize':
'ִ ε  ũ(MIME ũ)',

'userMembershipApprovalRequired':
'ȸԽ   䱸',

'errorLogging':
'α׻',

'numberOfArticlesInAPage':
'ƼŬ   ũ',

'numberOfTitlesInAPage':
'   ũ',

'numberOfUsersInAPage':
'   ũ',

'maxUserCache':
' ĳ',

'maxUserListCache':
'  ĳ',

'maxArticleCache':
'ƼŬ ĳ',

'maxThreadCachePerForum':
'  ĳ',

'sessionLife':
' ()',

'sessionRemoveProbability':
'  Ȯ',

'adminLevel':
' ',

'memberLevel':
'ȸ ',

'waitingLevel':
' ȸ ',

'Move Up':
'',

'Move Down':
'Ʒ',

'Change Name':
'̸',

'Delete Category':
'īװ ',

'Memberships':
'ȸ',

'New Category Name':
' īװ ̸',

'Create new forum':
'  ',

'Code':
'ڵ',

'Emoticon':
'̸Ƽ',

'Action':
'۾',

'File Name':
'̸',

'Register':
'',

'anonymousLevel':
'ȸ ',

'Create new Category':
' īװ ',

'I lost my password':
'н带 ؾȽϴ.',

'Receiver':
'޴ ',

'Sender':
' ',

'Message':
'޽',

'ReceiveMemoBox':
' ',

'SentMemoBox':
' ',

'Send Memo':
' ',

'To':
'޴ ',

'Send Date':
' ¥',

'Read Date':
' ¥',

'Not read':
' ',

'Using HTML Tag':
'HTML ± ',

'Using Emoticon':
'̸Ƽ ',

'Using BB Code':
'BB ڵ ',

'Notice':
'',

'Email Notification':
'̸ 뺸',

'File Upload':
' ÷',

'Send':
'',

'Sending Memo':
' ',

'\'s articles':
' ',

'\'s articles in':
'  >>',

'read my articles':
'  б',

'Forums I joined':
'  ',

'User Information':
' ',

'My Information':
' ',

'Information of':
' :',

'recently login time':
'ֱ α ð',

'No. of login':
'α Ƚ',

'No. of writings':
'ø ۼ',

'User Level':
' ',

'User Id':
' ̵',

'Contact':
'ó',

'invisible':
'',

'action is not defined':

'action ǵǾ  ʽϴ.',

'Wrong forumId':
'forumId ߸Ǿϴ.',

'no such user':
'ڸ ã  ϴ :',

'Invalid access.':
'߸ Դϴ.',

'This forum is locked':
'  ֽϴ.',

' is not found':
' ã ϴ.',

'not a valid user - ':
'  ƴմϴ - ',

'failed to register':
' ߽ϴ.',

'Membership approved':
'ȸ  Ǿϴ.',

'Invalid user':
'߸ ',

'You\'ve got memo from':
'޸ ߽ϴ:-',

'You have a new memo. Click the following link.':
'޸ ߽ϴ.  ũ Ŭؼ ȮϽñ ٶϴ',

'failed to send email notification':
'˸  ߼ ߽ϴ.',

'You need to login to proceed':
' ִ ڷ α ϼž    ֽϴ',

'Please enter your username and password to log in':
'αϷ  ̸ йȣ Էϼ',

'login failed. Try again':
'α . ٽ õϽñ ٶϴ.',

'changed password notification':
' йȣ ˸',

'changed password has been emailed to you':
' йȣ ϵ Ϸ ۵Ǿϴ.',

'new user is waiting for the membership approval':
'ο   ٸ ֽϴ.',


'Thank you for registration to ':
'ּż մϴ.',

'''Thank you for the registration to our community.

According to our policy, user membership will be given by the administrator.

A mail will be delivered to you when administrator approves your membership.''':
''' Ŀ´Ƽ ּż մϴ.
 ħ  ȸ    ʿմϴ.
 Ŀ  ߼۵Ǵ Ȯ ٶϴ.''',

'You already joined the forum':
'̹ Ե Դϴ.',

'You does not use \'anonymous\'.':
'ȸ ̿ մϴ.',

'You does not use specific character.':
'Ư ڴ   ϴ.',

'Your new password entries did not match.':
'н н Ȯ ġ ʽϴ.',

'Someone else has already chosen ID. Please try another ID.':
'ٸ   IDԴϴ. ٸ ID Ͻñ ٶϴ.',

'Invalid user or wrong password':
'߸  Ȥ ߸ н Դϴ',

'Sorry, you cannot join the forum':
' Ұ Դϴ.',

'Invalid userId or email':
'߸ ID Ȥ  ּԴϴ.',

'failed to send an email. contact to the webmaster':
' ߼ ߽ϴ. ڿ  ٶϴ.',

'You are waiting for approval. Try it later':
'    ʾҽϴ. ߿ ٽ õϽñ ٶϴ.',

'You are not a member of this community, anymore.':
'  Ŀ´Ƽ ȸ ƴմϴ.',

'the memo has been sent but email notification has not sent. check your SMTP server.':
'޸ ߼۵Ǿ ˸  ߼ ߽ϴ. SMTP  ȮϽñ ٶϴ.',

'the memo has been sent but email notification has not sent to the following users.':
'޸ ߼۵Ǿ  () ˸  ߼ ߽ϴ.',

'start tag &lt;%s&gt; not closed':
' ± &lt;%s&gt;   ʽϴ.',

'end tag &lt;/%s&gt; doesn\'t match start tag &lt;%s&gt;':
' ± &lt;/%s&gt;   ± &lt;%s&gt;  ġ ʽϴ.',

'Not well formed document : ':
'߸   : ',

'wellformed':
' ',

'the length of id should be in between 3 and 16':
'̵ ̴ 3 ̻ 16 Դϴ.',

'e-mail is not correct!':
' ʴ  ּԴϴ.',

'password field is empty!':
'н带 ֽñ ٶϴ.',

'password and password confirm does not matched':
'н н Ȯ ġ ʽϴ.',

'new password and password confirm does not matched':
' н н Ȯ ġ ʽϴ.',

'Invalid user id':
'ȿ   IDԴϴ',

'This member has not enough level to be a moderator':
' ȸ ڰ   ڰ   ʽϴ',

'Session expired. Login and try again':
' Ǿϴ. αϰ ٽ õϽñ ٶϴ',

'anonymous is not a registered user':
'anonymous ϵ ڰ ƴմϴ',

'avatar path might not be correct':
'ƹŸ ΰ Ȯ   ϴ.',

'Group Mail':
'׷ ',

'To Groups':
'õ ׷',

'Group List':
'׷ ',

'User Group':
' ׷',

'Add Forum':
' ߰ϱ',

'Edit Forum':
' ϱ',

'Registered User Group List':
'ϵ  ׷ ',

'Search Result':
'˻ ',

'no search result found':
'˻  ϴ.',

'Finding Lost My Password':
'н н ã',

# Statistic
'Today':
' ¥',

'Board Started Date':
'Խ ġ ¥',

'Elapsed Time':
'Խ ġ  ð',

'Size Of Used DB':
'Ÿ̽  뷮',

'Recently New User':
'ֱ  ',

'Latest Poster':
'ֱ Խ',

'Posts Of Today':
' ϵ Խù ',

'Posts Per Day':
'Ϸ  Խù ',

'Number Of Emoticons':
' ̸Ƽ ',

'Top Posters':
'Խù   ',

'Top Login Count Users':
'ְ Ȱ ',

'Top Read Count Threads':
'ȸ   Խù',

}

==> PyBB-0.9.1.tar.gz: PyBB-0.9.1/bbs/i18n/ko.py <==
'''
    PyBB - Language Korean

    Copyright (c) 2003-2004 Gang Seong Lee <gslee@mail.kw.ac.kr>
    All rights reserved, see COPYING for details.
'''

texts = {
'Username':
'ڸ',

'Password':
'н',

'Please enter your username and password to log in':
'ڸ н带 Էϰ αϽñ ٶϴ',

'Forum List':
' ',

'Edit Profile':
'',

'Message Box':
' ',

"Admin Page":
' ',

'Member List':
'ȸ ',

'Search':
'˻',

'Statistic':
'',

'Number of members':
'  ',

'Number of active members':
'Ȱ  ',

'Number of Categories':
'īװ ',

'Number of Forums':
' ',

'Number of threads':
'  ',

'Number of posts':
' Խñ ',

'Latest Post':
'ֱ Խñ',

'Join Us':
'ϱ',

'login':
'α',

'logout':
'α׾ƿ',

'Topics':
'',

'Posts':
'Խñ',

'Latest Post':
'ֱٱ',

'Moderator(s)':
'',

'Registration Information':
' ',

'Items marked with a * are required unless stated otherwise.':
'* ǥõ ׸ ʼԴϴ.',

'UserId': #  messages of userRegisterForm.html
' ID',

'E-mail address':
' ּ',

'Confirm password':
'н Ȯ',

'Profile Information':
' ',

'This information will be publicly viewable':
'  Գ ˴ϴ.',

'Messenger':
'޽',

'Website':
'Ȩ',

'Location':
'Ҽ',

'Occupation':
'',

'Interests':
'',

'Signature':
'',

'This is a block of text that can be added to posts you make. There is a 255 character limit':
'  ۼ  ڿ ٰ ˴ϴ. 255 ̳ ۼϽñ ٶϴ.',

'Preferences':
' ',

'Hide your online status':
'   ',

'Yes':
'',

'No':
'ƴϿ',

'Always notify me of replies':
'׻ 亯 ˸',

'Sends an e-mail when someone replies to a topic you have posted in. This can be changed whenever you post.':
' ۼ  亯 Ϸ ˷ 帳ϴ.  ۼҶ   ֽϴ.',

'Always notify me of memos':
'׻ ޸ ˸',

'email notification forum list':
'̸ 뺸  ',

'one forum each line':
' ٿ  ',

'Submit':
'Ȯ',

'Reset':
' ۼ',

'forum':
'',

'ALL':
'ü',

'Subject':
'',

'Contents':
'',

'User':
'',

'New Thread':
'ο ',

'Edit or Reply':
' Ǵ ',

'Topic':
'',

'Topic Starter':
'ۼ',

'Replies':
'亯',

'Views':
'ȸ',

'Latest Post':
'ֱ 亯',

'Comments':'',
'Last Comment':' ',

'New Password':
' н',

'New Confirm password':
' н Ȯ',

'Avator':
'ƹŸ',

'You can be upload your picture or avator here. it can be only gif or jpg format.':
'  Ǵ ׸ ø  ֽϴ.  GIF JPG ĸ մϴ.',

'Update':
'',

'Forum Name':
' ̸',

'Forum Description':
' ',

'Forum Type':
' ',

'Forum Status':
' ',

'locked':
'',

'unlocked':
' ',

'hidden':
'',

'Moderator':
' ',

'Permissions':
'',

'View':
'',

'all':
'ü',

'member':
'ȸ',

'forumMember':
' ȸ',

'moderator':
' ',

'userGroup':
' ׷',

'topicStarter':
' ',

'admin':
'ְ ',

'Read':
'б',

'Post':
'ۼ',

'Reply':
'亯',

'Edit':
'',

'List':
'',

'private':
'ۼ',

'Thumbnail SizeX':
' ʺ',

'Thumbnail SizeY':
' ',

'Thumbnail Columns':
'ٿ   ',

'Move':
'̵',

'Copy':
'',

'Delete':
'',

'Default Sort':
'⺻ ',

'Forum Skin':
' Ų',

'Forum Skin Type':
' Ų ',

'Thread id':
'Խù ȣ',

'Ascending':
'',

'Descending':
'',

'Create':
'ۼ',

'Forum Manager':
' ',

'User Manager':
'ȸ ',

'User Group Manager':
'ȸ ׷ ',

'Emoticon Manager':
'̸Ƽ ',

'Configuration Manager':
'ȯ ',

'Add Category':
'īװ ߰ϱ',

'Edit Category':
'īװ ϱ',

'Category Name':
'īװ ̸',

'Do not use':
' Ұ : ',

'Total':
'',

'members':
'',

'New Members (separated by space or new line)':
' ȸ ( Ǵ ͷ )',

'E-mail':
'',

'Level':
'',

'Registered Time':
'',

'Total Posts':
' ۼ',

'joined forums':
'Ե ',

'Change Level':
' ',

'Delete User':
' ',

'Poster':
'ۼ',

'IP':
'IP',

'Post Reply':
'亯ޱ',

'Do you really want to delete?':
' մϱ?',

'Previous Thread':
'',

'Next Thread':
'',

'prev':
'',

'next':
'',

'DB setup':
'DB ',

'DB tables':
'DB ̺ ',

'site information':
'Ʈ ',

'paths':
'',

'env':
'ȯ',

'page setup':
' ',

'cache':
'ĳ',

'session':
'',

'user levels':
' ',

'dbhost':
'DB ȣƮ',

'dbuser':
'DB ڰ',

'dbpassword':
'DB н',

'dbname':
'DB ̸',

'tablePrefix':
'̺ ̸ λ',

'userTableName':
' ̺ ̸',

'memoTableName':
'޸ ̺ ̸',

'membershipTableName':
'ȸ ̺ ̸',

'siteName':
'Ʈ',

'webmaster':
'',

'HOST_URL':
'ȣƮ URL',

'HTTP_PORT':
'HTTP Ʈ',

'boardStartedDate':
' ',

'dateFormat':
'¥ ǥ ',

'groupDescFileName':
'׷켳 ',

'urlPrefix':
'url ξ',

'skinPath':
'Ų 丮 ',

'skinImagePath':
'Ų ̹ 丮 ',

'sessionDir':
' 丮 ',

'charset':
' ڵ',

'defaultLanguage':
'⺻(    쿡 ǥõǴ )',

'maxFileSize':
'ִ ε  ũ(MIME ũ)',

'userMembershipApprovalRequired':
'ȸԽ   䱸',

'errorLogging':
'α׻',

'newUserEmailNotification':
' ȸ Խ ̸ ˸',

'bannedExtensions':
'ε  Ȯ',

'numberOfSearchResultsInAPage':
'˻    ũ',

'Number Of Articles In a Page':
'ƼŬ   ũ',

'Number Of Titles In a Page':
'   ũ',

'numberOfUsersInAPage':
'   ũ',

'maxUserCache':
' ĳ',

'maxUserListCache':
'  ĳ',

'maxArticleCache':
'ƼŬ ĳ',

'maxThreadCachePerForum':
'  ĳ',

'sessionLife':
' ()',

'sessionRemoveProbability':
'  Ȯ',

'adminLevel':
' ',

'memberLevel':
'ȸ ',

'waitingLevel':
' ȸ ',

'ip control':
'ip ',

'machine blocking':
'κ ',

'read/write blocking':
'б/ ',

'folding':
'īװ ',

'unfolding':
'īװ ġ',

'Move Up':
'',

'Move Down':
'Ʒ',

'Change Name':
'̸',

'Delete Category':
'īװ ',

'Merge Forum':
' ġ',

'Merge':
'ġ',

'Target Thread No':
'ĥ  ȣ',
    
'Actions':
' ',

'Source':
' ',

'Target':
'',

'source forum or target forum is not correct.':
'    ϴ.',

'Do you really want to merge?':
'  ġðڽϱ? Ŀ    ϴ.',

'Memberships':
'ȸ',

'New Category Name':
' īװ ̸',

'Create new forum':
'  ',

'Code':
'ڵ',

'Emoticon':
'̸Ƽ',

'Action':
'۾',

'File Name':
'̸',

'Register':
'',

'anonymousLevel':
'ȸ ',

'Create new Category':
' īװ ',

'I lost my password':
'н带 ؾȽϴ.',

'Receiver':
'޴ ',

'Sender':
' ',

'Message':
'޽',

'ReceiveMemoBox':
' ',

'SentMemoBox':
' ',

'Send Memo':
' ',

'To':
'޴ ',

'Send Date':
' ¥',

'Read Date':
' ¥',

'Not read':
' ',

'Using HTML Tag':
'HTML ± ',

'Using Emoticon':
'̸Ƽ ',

'Using BB Code':
'BB ڵ ',

'Notice':
'',

'Email Notification':
'̸ 뺸',

'File Upload':
' ÷',

'Send':
'',

'Sending Memo':
' ',

'\'s articles':
' ',

'\'s articles in':
'  >>',

'read my articles':
'  б',

'Forums I joined':
'  ',

'User Information':
' ',

'My Information':
' ',

'Information of':
' :',

'recently login time':
'ֱ α ð',

'No. of login':
'α Ƚ',

'No. of writings':
'ø ۼ',

'User Level':
' ',

'User Id':
' ̵',

'Contact':
'ó',

'invisible':
'',

'Read time':
' ð',

'action is not defined':

'action ǵǾ  ʽϴ.',

'Wrong forumId':
'forumId ߸Ǿϴ.',

'no such user':
'ڸ ã  ϴ :',

'Invalid access.':
'߸ Դϴ.',

'This forum is locked':
'  ֽϴ.',

' is not found':
' ã ϴ.',

'not a valid user - ':
'  ƴմϴ - ',

'failed to register':
' ߽ϴ.',

'Membership approved':
'ȸ  Ǿϴ.',

'Invalid user':
'߸ ',

'You\'ve got memo from':
'޸ ߽ϴ:-',

'You have a new memo. Click the following link.':
'޸ ߽ϴ.  ũ Ŭؼ ȮϽñ ٶϴ',

'failed to send email notification':
'˸  ߼ ߽ϴ.',

'You need to login to proceed':
' ִ ڷ α ϼž    ֽϴ',

'Please enter your username and password to log in':
'αϷ  ̸ йȣ Էϼ',

'login failed. Try again':
'α . ٽ õϽñ ٶϴ.',

'changed password notification':
' йȣ ˸',

'changed password has been emailed to you':
' йȣ ϵ Ϸ ۵Ǿϴ.',

'new user is waiting for the membership approval':
'ο   ٸ ֽϴ.',


'Thank you for registration to ':
'ּż մϴ.',

'''Thank you for the registration to our community.
According to our policy, user membership will be given by the administrator.
A mail will be delivered to you when administrator approves your membership.''':
''' Ŀ´Ƽ ּż մϴ.
 ħ  ȸ    ʿմϴ.
 Ŀ  ߼۵Ǵ Ȯ ٶϴ.''',

'Thank you for registering. Now you are a member of this site. Enjoy your time.':
'ȸ Ǽ̽ϴ. ּż 帳ϴ. ð ǽñ ٶϴ',

'You already joined the forum':
'̹ Ե Դϴ.',

'You does not use \'anonymous\'.':
'ȸ ̿ մϴ.',

'You does not use specific character.':
'Ư ڴ   ϴ.',

'Your new password entries did not match.':
'н н Ȯ ġ ʽϴ.',

'Someone else has already chosen ID. Please try another ID.':
'ٸ   IDԴϴ. ٸ ID Ͻñ ٶϴ.',

'Invalid user or wrong password':
'߸  Ȥ ߸ н Դϴ',

'Sorry, you cannot join the forum':
' Ұ Դϴ.',

'Invalid userId or email':
'߸ ID Ȥ  ּԴϴ.',

'failed to send an email. contact to the webmaster':
' ߼ ߽ϴ. ڿ  ٶϴ.',

'You are waiting for approval. Try it later':
'    ʾҽϴ. ߿ ٽ õϽñ ٶϴ.',

'You are not a member of this community, anymore.':
'  Ŀ´Ƽ ȸ ƴմϴ.',

'the memo has been sent but email notification has not sent. check your SMTP server.':
'޸ ߼۵Ǿ ˸  ߼ ߽ϴ. SMTP  ȮϽñ ٶϴ.',

'the memo has been sent but email notification has not sent to the following users.':
'޸ ߼۵Ǿ  () ˸  ߼ ߽ϴ.',

'start tag &lt;%s&gt; not closed':
' ± &lt;%s&gt;   ʽϴ.',

'end tag &lt;/%s&gt; doesn\'t match start tag &lt;%s&gt;':
' ± &lt;/%s&gt;   ± &lt;%s&gt;  ġ ʽϴ.',

'Not well formed document : ':
'߸   : ',

'wellformed':
' ',

'the length of id should be in between 3 and 16':
'̵ ̴ 3 ̻ 16 Դϴ.',

'e-mail is not correct!':
' ʴ  ּԴϴ.',

'password field is empty!':
'н带 ֽñ ٶϴ.',

'password and password confirm does not matched':
'н н Ȯ ġ ʽϴ.',

'new password and password confirm does not matched':
' н н Ȯ ġ ʽϴ.',

'Invalid user id':
'ȿ   IDԴϴ',

'This member has not enough level to be a moderator':
' ȸ ڰ   ڰ   ʽϴ',

'Login and try again':
'αϰ ٽ õϽñ ٶϴ',

'anonymous is not a registered user':
'anonymous ϵ ڰ ƴմϴ',

'avatar path might not be correct':
'ƹŸ ΰ Ȯ   ϴ.',

'Group Mail':
'׷ ',

'To Groups':
'õ ׷',

'Group List':
'׷ ',

'User Group Select':
' ׷ ',

'User Group':
' ׷',

'Email Notice User Group':
'Ͼ˸   ׷',

'Add Forum':
' ߰ϱ',

'Edit Forum':
' ϱ',

'Registered User Group List':
'ϵ  ׷ ',

'Search Result':
'˻ ',

'no search result found':
'˻  ϴ.',

'Finding Lost My Password':
'н н ã',

# Statistic
'Today':
' ¥',

'Board Started Date':
'Խ ġ ¥',

'Elapsed Time':
'Խ ġ  ð',

'Size Of Used DB':
'Ÿ̽  뷮',

'Recently New User':
'ֱ  ',

'Latest Poster':
'ֱ Խ',

'Posts Of Today':
' ϵ Խù ',

'Posts Per Day':
'Ϸ  Խù ',

'Number Of Emoticons':
' ̸Ƽ ',

'Top Posters':
'Խù   ',

'Top Login Count Users':
'ְ Ȱ ',

'Top Read Count Threads':
'ȸ   Խù',

'Not exist frorum name(s)':
'߸ ̸()',

# photo gallery
'Add comment': 'ޱ',

'machineBlocking':'ӽ ŷ ',
'readBlockingTime':'б  ð',
'writeBlockingTime':'  ð',
'allowedMaxNumberOfArticlesToWritePerIpADay':'IP Ϸ翡   ִ  ',
'allowedMaxNumberOfArticlesToReadPerIpADay':'IP Ϸ翡   ִ  ',

'allowIpList':
' IP ',
'denyIpList':
' Ip ',
}
